@@ -78,6 +78,7 @@ async fn handle_file(scanners: Arc<Vec<Box<dyn FileScanner>>>, entry: walkdir::D
                 }
 
                 Ok(res) => {
+                    log::trace!("new finding from {} for {}", scanner, entry.path().display());
                     result.add_finding(res);
                 }
             }
@@ -138,7 +139,7 @@ impl Dionysos {
                 .into_iter()
                 .filter_map(|e| e.ok())
                 .filter(|e| e.file_type().is_file()) {
-            log::info!("scanning '{}'", entry.file_name().to_string_lossy());
+            log::info!("scanning '{}'", entry.path().display());
             while workers.len() >= max_workers {
                 let selector_future = future::select_all(workers);
                 let (result, _, wrkrs) = block_on(selector_future);
