@@ -2,6 +2,7 @@ use walkdir::DirEntry;
 
 use crate::filescanner::*;
 use crate::scanner_result::{ScannerFinding};
+use std::fmt::Display;
 use std::path::Path;
 pub struct LevenshteinScanner {
     wellknown_files: Vec<Vec<char>>
@@ -32,6 +33,12 @@ impl FileScanner for LevenshteinScanner {
     }
 }
 
+impl Display for LevenshteinScanner {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        write!(f, "{}", "LevenshteinScanner")
+    }
+}
+
 impl LevenshteinScanner {
     fn intern_scan_file(&self, file: &Path) -> Vec<anyhow::Result<ScannerFinding>> {        
         match file.file_name() {
